import type { AccountNode } from './AccountNode';
import type { DefinedTypeNode } from './DefinedTypeNode';
import type { ErrorNode } from './ErrorNode';
import type { InstructionAccountNode } from './InstructionAccountNode';
import type { InstructionArgumentNode } from './InstructionArgumentNode';
import type { InstructionByteDeltaNode } from './InstructionByteDeltaNode';
import type { InstructionNode } from './InstructionNode';
import type { InstructionRemainingAccountsNode } from './InstructionRemainingAccountsNode';
import type { PdaNode } from './PdaNode';
import type { ProgramNode } from './ProgramNode';
import type { RootNode } from './RootNode';
declare const REGISTERED_NODES: {
    mapEntryValueNode: import("src").MapEntryValueNode;
    structFieldValueNode: import("src").StructFieldValueNode;
    arrayValueNode: import("src").ArrayValueNode;
    booleanValueNode: import("src").BooleanValueNode;
    enumValueNode: import("src").EnumValueNode;
    mapValueNode: import("src").MapValueNode;
    noneValueNode: import("src").NoneValueNode;
    numberValueNode: import("src").NumberValueNode;
    setValueNode: import("src").SetValueNode;
    someValueNode: import("src").SomeValueNode;
    structValueNode: import("src").StructValueNode;
    tupleValueNode: import("src").TupleValueNode;
    publicKeyValueNode: import("src").PublicKeyValueNode;
    stringValueNode: import("src").StringValueNode;
    structFieldTypeNode: import("src").StructFieldTypeNode;
    enumEmptyVariantTypeNode: import("src").EnumEmptyVariantTypeNode;
    enumStructVariantTypeNode: import("src").EnumStructVariantTypeNode;
    enumTupleVariantTypeNode: import("src").EnumTupleVariantTypeNode;
    amountTypeNode: import("src").AmountTypeNode;
    arrayTypeNode: import("src").ArrayTypeNode;
    booleanTypeNode: import("src").BooleanTypeNode;
    bytesTypeNode: import("src").BytesTypeNode;
    dateTimeTypeNode: import("src").DateTimeTypeNode;
    enumTypeNode: import("src").EnumTypeNode;
    mapTypeNode: import("src").MapTypeNode;
    numberTypeNode: import("src").NumberTypeNode;
    optionTypeNode: import("src").OptionTypeNode;
    publicKeyTypeNode: import("src").PublicKeyTypeNode;
    setTypeNode: import("src").SetTypeNode;
    solAmountTypeNode: import("src").SolAmountTypeNode;
    stringTypeNode: import("src").StringTypeNode;
    structTypeNode: import("src").StructTypeNode;
    tupleTypeNode: import("src").TupleTypeNode;
    fixedSizeNode: import("src").FixedSizeNode;
    remainderSizeNode: import("src").RemainderSizeNode;
    prefixedSizeNode: import("src").PrefixedSizeNode;
    constantPdaSeedNode: import("src").ConstantPdaSeedNode;
    programIdPdaSeedNode: import("src").ProgramIdPdaSeedNode;
    variablePdaSeedNode: import("src").VariablePdaSeedNode;
    programLinkNode: import("src").ProgramLinkNode;
    pdaLinkNode: import("src").PdaLinkNode;
    accountLinkNode: import("src").AccountLinkNode;
    definedTypeLinkNode: import("src").DefinedTypeLinkNode;
    byteDiscriminatorNode: import("src").ByteDiscriminatorNode;
    fieldDiscriminatorNode: import("src").FieldDiscriminatorNode;
    sizeDiscriminatorNode: import("src").SizeDiscriminatorNode;
    pdaSeedValueNode: import("src").PdaSeedValueNode;
    accountBumpValueNode: import("src").AccountBumpValueNode;
    accountValueNode: import("src").AccountValueNode;
    argumentValueNode: import("src").ArgumentValueNode;
    conditionalValueNode: import("src").ConditionalValueNode;
    identityValueNode: import("src").IdentityValueNode;
    payerValueNode: import("src").PayerValueNode;
    pdaValueNode: import("src").PdaValueNode;
    programIdValueNode: import("src").ProgramIdValueNode;
    resolverValueNode: import("src").ResolverValueNode;
    rootNode: RootNode;
    programNode: ProgramNode;
    pdaNode: PdaNode;
    accountNode: AccountNode;
    instructionAccountNode: InstructionAccountNode;
    instructionArgumentNode: InstructionArgumentNode;
    instructionByteDeltaNode: InstructionByteDeltaNode;
    instructionNode: InstructionNode;
    instructionRemainingAccountsNode: InstructionRemainingAccountsNode;
    errorNode: ErrorNode;
    definedTypeNode: DefinedTypeNode;
};
export declare const REGISTERED_NODE_KINDS: ("arrayValueNode" | "booleanValueNode" | "enumValueNode" | "mapValueNode" | "noneValueNode" | "numberValueNode" | "setValueNode" | "someValueNode" | "structValueNode" | "tupleValueNode" | "publicKeyValueNode" | "stringValueNode" | "mapEntryValueNode" | "structFieldValueNode" | "structFieldTypeNode" | "enumEmptyVariantTypeNode" | "enumStructVariantTypeNode" | "enumTupleVariantTypeNode" | "amountTypeNode" | "arrayTypeNode" | "booleanTypeNode" | "bytesTypeNode" | "dateTimeTypeNode" | "enumTypeNode" | "mapTypeNode" | "numberTypeNode" | "optionTypeNode" | "publicKeyTypeNode" | "setTypeNode" | "solAmountTypeNode" | "stringTypeNode" | "structTypeNode" | "tupleTypeNode" | "fixedSizeNode" | "remainderSizeNode" | "prefixedSizeNode" | "constantPdaSeedNode" | "programIdPdaSeedNode" | "variablePdaSeedNode" | "programLinkNode" | "pdaLinkNode" | "accountLinkNode" | "definedTypeLinkNode" | "byteDiscriminatorNode" | "fieldDiscriminatorNode" | "sizeDiscriminatorNode" | "pdaSeedValueNode" | "accountBumpValueNode" | "accountValueNode" | "argumentValueNode" | "conditionalValueNode" | "identityValueNode" | "payerValueNode" | "pdaValueNode" | "programIdValueNode" | "resolverValueNode" | "rootNode" | "programNode" | "pdaNode" | "accountNode" | "instructionAccountNode" | "instructionArgumentNode" | "instructionByteDeltaNode" | "instructionNode" | "instructionRemainingAccountsNode" | "errorNode" | "definedTypeNode")[];
export type NodeDictionary = typeof REGISTERED_NODES;
export type NodeKind = keyof NodeDictionary;
export type Node = NodeDictionary[NodeKind];
export declare function isNode<TKind extends NodeKind>(node: Node | null | undefined, kind: TKind | TKind[]): node is NodeDictionary[TKind];
export declare function assertIsNode<TKind extends NodeKind>(node: Node | null | undefined, kind: TKind | TKind[]): asserts node is NodeDictionary[TKind];
export declare function isNodeFilter<TKind extends NodeKind>(kind: TKind | TKind[]): (node: Node | null | undefined) => node is NodeDictionary[TKind];
export declare function assertIsNodeFilter<TKind extends NodeKind>(kind: TKind | TKind[]): (node: Node | null | undefined) => node is NodeDictionary[TKind];
export declare function removeNullAndAssertIsNodeFilter<TKind extends NodeKind>(kind: TKind | TKind[]): (node: Node | null | undefined) => node is NodeDictionary[TKind];
export {};
